# InvPlaybookTaskCompleteData

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**arguments** | **dict(str, object)** |  | [optional] 
**completed_by** | **str** |  | [optional] 
**completed_count** | **int** |  | [optional] 
**completed_date** | **datetime** |  | [optional] 
**entries** | **list[str]** |  | [optional] 
**input** | **str** |  | [optional] 
**outputs** | **dict(str, object)** |  | [optional] 
**playbook_inputs** | **dict(str, object)** |  | [optional] 
**start_date** | **datetime** |  | [optional] 
**state** | [**TaskState**](TaskState.md) |  | [optional] 
**will_not_execute_count** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


